<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>ConkyCustomizeDialog</name>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="56"/>
        <source>Customize Conky - %1</source>
        <translation>Mukauta Conky - %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="77"/>
        <source>Launch</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="81"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Start</source>
        <translation>Aloita</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="83"/>
        <source>Undo</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="106"/>
        <location filename="../src/conkycustomizedialog.cpp" line="186"/>
        <source>Colors</source>
        <translation>Värit</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Default</source>
        <translation>Oletus</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color0</source>
        <translation>Väri0 </translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color1</source>
        <translation>Väri1 </translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color2</source>
        <translation>Väri2 </translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color3</source>
        <translation>Väri3 </translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color4</source>
        <translation>Väri4 </translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color5</source>
        <translation>Väri5</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color6</source>
        <translation>Väri6</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color7</source>
        <translation>Väri7</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color8</source>
        <translation>Väri8</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color9</source>
        <translation>Väri9</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="193"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="337"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Stop</source>
        <translation>Pysäytä</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="684"/>
        <source>Select Color</source>
        <translation>Valitse väri</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="790"/>
        <source>Permission Denied</source>
        <translation>Ei käyttöoikeutta</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="791"/>
        <source>Cannot write to file: %1
Insufficient permissions.</source>
        <translation>Ei voi kirjoittaa tiedostoon: %1
Riittämättömät käyttöoikeudet.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="801"/>
        <source>Write Error</source>
        <translation>Kirjoitusvirhe</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="801"/>
        <source>Cannot write to file: %1</source>
        <translation>Ei voi kirjoittaa tiedostoon: %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="874"/>
        <source>Backup Config File</source>
        <translation>Varmuuskopioi asetustiedosto</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="874"/>
        <source>Do you want to preserve the original file?</source>
        <translation>Haluatko säilyttää alkuperäisen tiedoston?</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="897"/>
        <source>Backed Up Config File</source>
        <translation>Varmuuskopioitu asetustiedosto</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="898"/>
        <source>The original configuration was backed up to %1</source>
        <translation>Alkuperäinen asetus varmistettiin tiedostoon %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="900"/>
        <source>Backup Failed</source>
        <translation>Varmuuskopio epäonnistui</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="900"/>
        <source>Failed to create a backup file.</source>
        <translation>Varmistuksen luominen epäonnistui.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="973"/>
        <location filename="../src/conkycustomizedialog.cpp" line="976"/>
        <source>Restore Failed</source>
        <translation>Palautus epäonnistui</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="973"/>
        <source>Failed to restore from backup file.</source>
        <translation>Palautus varmuuskopiosta epäonnistui.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="976"/>
        <source>Backup file does not exist.</source>
        <translation>Varmuuskopiota ei ole olemassa.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1328"/>
        <source>Position</source>
        <translation>Asento</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1335"/>
        <source>Alignment</source>
        <translation>Tasattu</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1340"/>
        <source>Top Left</source>
        <translation>Vasen yläkulma</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1341"/>
        <source>Top Right</source>
        <translation>Oikea yläkulma</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1342"/>
        <source>Top Middle</source>
        <translation>Yläosa keskellä</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1343"/>
        <source>Bottom Left</source>
        <translation>Vasen alakulma</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1344"/>
        <source>Bottom Right</source>
        <translation>Oikea alakulma</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1345"/>
        <source>Bottom Middle</source>
        <translation>Alaosa keskellä</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1346"/>
        <source>Middle Left</source>
        <translation>Keskellä vasemmalla</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1347"/>
        <source>Middle Right</source>
        <translation>Keskellä oikealla</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1348"/>
        <source>Middle Middle</source>
        <translation>Keskipiste</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1353"/>
        <source>Horizontal Gap</source>
        <translation>Vaakaetäisyys</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1354"/>
        <source>[GAP_X] Horizontal distance from window border (in pixels)</source>
        <translation>[GAP_X] Vaakasuora etäisyys ikkunan reunasta (pikseleinä)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1366"/>
        <source>Vertical Gap</source>
        <translation>Pystyetäisyys</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1367"/>
        <source>[GAP_Y] Vertical distance from window border (in pixels)</source>
        <translation>[GAP_Y] Pystysuora etäisyys ikkunan reunasta (pikseleinä)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1379"/>
        <source>Desktop</source>
        <translation>Työpöytä</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1382"/>
        <source>Desktop 1</source>
        <translation>Työpöytä 1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1383"/>
        <source>All Desktops</source>
        <translation>Kaikki työpöydät</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1395"/>
        <source>Location</source>
        <translation>Paikka</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1407"/>
        <source>Width should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>Leveyden tulisi olla suurempi kuin ikkunan sisällön koko,
muuten asetuksella ei ole vaikutusta.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1411"/>
        <source>Minimum Width</source>
        <translation>Minimileveys</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1426"/>
        <source>Height should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>Korkeuden tulisi olla suurempi kuin ikkunan sisällön koko,
muuten asetuksella ei ole vaikutusta.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1428"/>
        <source>Minimum Height</source>
        <translation>Minimikorkeus</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1442"/>
        <source>Increases the window height by adding empty lines at the end of the Conky config file</source>
        <translation>Suurentaa ikkunan korkeutta lisäämällä tyhjiä rivejä Conky-määritystiedoston loppuun</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1443"/>
        <source>Height Padding</source>
        <translation>Korkeuspehmuste</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1458"/>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1471"/>
        <source>Transparency Type</source>
        <translation>Läpinäkyvyys</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1476"/>
        <source>Opaque</source>
        <translation>Läpinäkymätön</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1477"/>
        <source>Transparent</source>
        <translation>Läpinäkyvä</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1478"/>
        <source>Pseudo-Transparent</source>
        <translation>Näennäisläpinäkyvä</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1479"/>
        <source>Semi-Transparent</source>
        <translation>Puoliläpinäkyvä</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1484"/>
        <source>Opacity (%)</source>
        <translation>Peittävyys (%)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1485"/>
        <source>Window Opacity

0 = Fully Transparent, 100 = Fully Opaque</source>
        <translation>Ikkunan läpinäkyvyys

0 = Täysin läpinäkyvä, 100 = Täysin läpinäkymätön</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1499"/>
        <source>Background Color</source>
        <translation>Taustaväri</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1504"/>
        <source>Choose Color</source>
        <translation>Valitse väri</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1524"/>
        <source>Setting Type to &quot;Transparent&quot; will make the whole window transparent (including any images). Use &quot;Pseudo-Transparent&quot; if you want the images to be opaque.</source>
        <translation>Asettaminen arvoon &quot;Läpinäkyvä&quot; se tekee koko ikkunasta läpinäkyvän (mukaan lukien kaikki kuvat). Käytä arvoa &quot;Näennäisläpinäkyvä&quot;, jos haluat kuvien olevan läpinäkymättömiä.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1534"/>
        <source>Setting Type to &quot;Pseudo-Transparent&quot; will make the window transparent but the window will have a shadow. The shadow can be disabled by configuring your window manager.</source>
        <translation>Asettaminen arvoon &quot;Näennäisläpinäkyvä&quot; tekee ikkunasta läpinäkyvän, mutta ikkunaan tulee varjo. Varjon voi poistaa käytöstä ikkunanhallinan asetuksista.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1545"/>
        <source>Transparency</source>
        <translation>Läpinäkyvä</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1556"/>
        <source>Date Format</source>
        <translation>Päiväyksen muoto</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1559"/>
        <source>Day</source>
        <translation>Päivämäärä</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1561"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1572"/>
        <source>Long</source>
        <translation>Pitkä</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1562"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1573"/>
        <source>Short</source>
        <translation>Lyhyt</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1563"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Nimi lyhennetty, esim. ti</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1570"/>
        <source>Month</source>
        <translation>Kuukausi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1574"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Nimi lyhennetty, esim. Tam</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1593"/>
        <source>Time Format</source>
        <translation>Kellonaika</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1600"/>
        <source>Format</source>
        <translation>Aika muodossa</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1605"/>
        <source>12 Hour</source>
        <translation>12H</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1606"/>
        <source>24 Hour</source>
        <translation>24H</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1621"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Päivämäärä &amp;&amp; aika</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1634"/>
        <source>Interface</source>
        <translation>Käyttöliittymä</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1642"/>
        <source>WiFi</source>
        <translation>WiFi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1645"/>
        <source>WiFi Network</source>
        <translation>WiFi verkko</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1648"/>
        <source>LAN</source>
        <translation>LAN</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1651"/>
        <source>Wired LAN Network</source>
        <translation>Kiinteä LAN verkko</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1665"/>
        <source>Network</source>
        <translation>Verkko</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1928"/>
        <source>Select Background Color</source>
        <translation>Valitse taustaväri</translation>
    </message>
</context>
<context>
    <name>ConkyItemWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="63"/>
        <source>Running</source>
        <translation>Käynnissä</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="63"/>
        <source>Stopped</source>
        <translation>Pysäytetty</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="118"/>
        <source>Autostart</source>
        <translation>Autom. käynnistys</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="120"/>
        <source>Edit</source>
        <translation>Muokkaa</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="123"/>
        <source>Customize</source>
        <translation>Mukauta</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="128"/>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="157"/>
        <source>Stop</source>
        <translation>Pysäytä</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="160"/>
        <source>Start</source>
        <translation>Käynnistä</translation>
    </message>
</context>
<context>
    <name>ConkyListWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="319"/>
        <source>Total: 0 conkies</source>
        <translation>Yhteensä: 0 conkia</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="551"/>
        <source>Total: %1 conkies</source>
        <translation>Yhteensä: %1 conkia</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="554"/>
        <source>Showing: %1 of %2 conkies</source>
        <translation>Näytetään: %1 - %2 conkia</translation>
    </message>
</context>
<context>
    <name>ConkyPreviewWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="503"/>
        <source>No Conky Selected</source>
        <translation>Ei valittua Conkya</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="505"/>
        <source>Select a conky from the list to see its preview</source>
        <translation>Valitse conky luettelosta ja katso sen esikatselu</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="524"/>
        <source>Preview image could not be loaded</source>
        <translation>Esikatselukuvan lataaminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="527"/>
        <source>No preview image available</source>
        <translation>Esikatselukuvaa ei ole saatavilla</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="56"/>
        <location filename="../src/mainwindow.cpp" line="814"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="234"/>
        <source>About this application</source>
        <translation>Tietoja sovelluksesta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="232"/>
        <source>About...</source>
        <translation>Tietoja...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="239"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="254"/>
        <source>Quit application</source>
        <translation>Sulje sovellus</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="252"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="149"/>
        <source>Loading Conky configurations...</source>
        <translation>Ladataan Conky-asetuksia...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="172"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="174"/>
        <source>Configure conky search paths</source>
        <translation>Määritä conky-hakupolut</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="176"/>
        <source>Refresh</source>
        <translation>Virkistä</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="178"/>
        <source>Refresh conky list</source>
        <translation>Virkistä conky lista</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="180"/>
        <source>Start All</source>
        <translation>Käynnistä kaikki</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="182"/>
        <source>Start all enabled conkies</source>
        <translation>Käynnistää kaikki käytössä olevat conkit</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="184"/>
        <source>Stop All</source>
        <translation>Pysäytä kaikki</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="186"/>
        <source>Stop all running conkies</source>
        <translation>Pysäytä kaikki ajossa olevat conkit</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="916"/>
        <location filename="../src/mainwindow.cpp" line="953"/>
        <source>Running</source>
        <translation>Käynnissä</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="918"/>
        <location filename="../src/mainwindow.cpp" line="954"/>
        <source>Stopped</source>
        <translation>Pysäytetty</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="194"/>
        <source>Search conky by name...</source>
        <translation>Hae conky nimellä...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="196"/>
        <source>Search conkies by name (Ctrl+F)</source>
        <translation>Hae conky nimellä (Ctrl+F)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="241"/>
        <source>Display help</source>
        <translation>Näytä ohje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="417"/>
        <location filename="../src/mainwindow.cpp" line="593"/>
        <source>Copy Conky</source>
        <translation>Kopioi Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="463"/>
        <location filename="../src/mainwindow.cpp" line="641"/>
        <source>Conky Copied</source>
        <translation>Conky kopioitu</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="464"/>
        <source>Conky has been copied to your personal folder for editing:
%1</source>
        <translation>Conky on kopioitu kansioosi muokkausta varten:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="466"/>
        <location filename="../src/mainwindow.cpp" line="644"/>
        <source>Copy Failed</source>
        <translation>Kopiointi epäonnistui</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="466"/>
        <location filename="../src/mainwindow.cpp" line="644"/>
        <source>Failed to copy conky to your personal folder.</source>
        <translation>Conky-tiedoston kopioiminen kansioosi epäonnistui.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="528"/>
        <source>Delete Conky</source>
        <translation>Poista Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="642"/>
        <source>Conky has been copied to your personal folder for customization:
%1</source>
        <translation>Conky on kopioitu kansioosi muokkausta varten:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>Delete Successful</source>
        <translation>Poistaminen onnistui</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="168"/>
        <source>Previews</source>
        <translation>Esikatselut</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="170"/>
        <source>Generate preview images for conkies</source>
        <translation>Luo esikatselukuvia conkieille</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="190"/>
        <location filename="../src/mainwindow.cpp" line="451"/>
        <location filename="../src/mainwindow.cpp" line="629"/>
        <location filename="../src/mainwindow.cpp" line="914"/>
        <location filename="../src/mainwindow.cpp" line="952"/>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="191"/>
        <source>Filter conkies by running status or location</source>
        <translation>Suodata conkit ajotilan tai paikan mukaan</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="413"/>
        <location filename="../src/mainwindow.cpp" line="589"/>
        <source>Enter a name for the copy:</source>
        <translation>Anna kopiolle nimi:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="414"/>
        <location filename="../src/mainwindow.cpp" line="590"/>
        <source>In order for you to edit and save a conky, it must first be copied to ~/.conky where you have permission.
Enter a name for the copy.</source>
        <translation>Jotta voit muokata tai tallentaa conky-tiedoston, se on ensin kopioitava kansioon ~/.conky, johon sinulla on käyttöoikeudet.
Anna kopiolle nimi.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="431"/>
        <location filename="../src/mainwindow.cpp" line="609"/>
        <source>Directory Exists</source>
        <translation>Kansio on olemassa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="432"/>
        <location filename="../src/mainwindow.cpp" line="610"/>
        <source>A conky with the name &apos;%1&apos; already exists in your personal folder.
Do you want to overwrite it?</source>
        <translation>Kansiossasi on jo conky nimeltä &quot;%1&quot;. Haluatko korvata?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="499"/>
        <source>Edit Conky</source>
        <translation>Muokkaa Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="500"/>
        <source>This conky file is read-only and requires administrator privileges to edit.
Do you want to edit it with elevated privileges?</source>
        <translation>Tämä conky on vain lukumuodossa ja muokkaamiseen vaaditaan järjestelmänvalvojan oikeudet.
Haluatko muokata sitä laajennetuilla oikeuksilla?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="529"/>
        <source>Are you sure you want to delete the conky file:
%1

This action cannot be undone.</source>
        <translation>Haluatko poistaa conky-tiedoston:
%1
Toimintoa ei voi perua.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="561"/>
        <source>Conky file deleted successfully.</source>
        <translation>Conky-tiedoston poistaminen onnistui.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="563"/>
        <source>Delete Failed</source>
        <translation>Poisto epäonnistui</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="563"/>
        <source>Failed to delete conky file:
%1</source>
        <translation>Conky-tiedoston poisto epäonnistui:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="651"/>
        <source>Customize Conky</source>
        <translation>Mukauta Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="652"/>
        <source>This conky file is read-only and requires administrator privileges to customize.
Do you want to customize it with elevated privileges?</source>
        <translation>Tämä conky on vain lukumuodossa ja muokkaamiseen vaaditaan järjestelmänvalvojan oikeudet.
Haluatko muokata sitä laajennetuilla oikeuksilla?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="803"/>
        <source>Editor Error</source>
        <translation>Editorin virhe</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="803"/>
        <source>Cannot start editor for file: %1</source>
        <translation>Tiedoston muokkausta ei voi käynnistää: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="813"/>
        <source>About MX Conky</source>
        <translation>Lisätietoja MX Conky:sta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="815"/>
        <source>Version: </source>
        <translation>Versio: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="816"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Ohjelma Conkyn konfigurointiin MX Linux:ssa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="819"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="820"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="821"/>
        <location filename="../src/mainwindow.cpp" line="833"/>
        <source>Changelog</source>
        <translation>Muutosloki</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="822"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="844"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="875"/>
        <source>MX Conky Help</source>
        <translation>MX Conky ohje</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <location filename="../src/previewdialog.cpp" line="50"/>
        <source>Generate Preview</source>
        <translation>Luo esikatselu</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="75"/>
        <source>Generate preview images for</source>
        <translation>Luo esikatselukuvat kohteelle</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="78"/>
        <source>Selected Widget</source>
        <translation>Valittu widgetti</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="79"/>
        <source>All Widgets with Missing Previews</source>
        <translation>Kaikki widgetit, joissa esikatselu puuttuu</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="80"/>
        <source>All Widgets (Overwrite Existing Images)</source>
        <translation>Kaikki widgetit (korvaa nykyiset kuvat)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="85"/>
        <source>No conky is currently selected</source>
        <translation>Conkya ei ole valittuna tällä hetkellä</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="93"/>
        <source>Options</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="96"/>
        <source>High quality images (PNG)</source>
        <translation>Korkealaatuiset kuvat (PNG)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="97"/>
        <source>Generate preview images in PNG format instead of JPEG</source>
        <translation>Luo esikatselukuvat png-formaatissa, jpeg:n sijaan</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="114"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="118"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No Items</source>
        <translation>Ei kohteita</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No conky widgets need preview generation.</source>
        <translation>Mikään conky-widgetti ei tarvitse esikatselun luomista.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="155"/>
        <source>Starting preview generation...</source>
        <translation>Esikatselun luominen alkoi...</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="159"/>
        <source>Stop</source>
        <translation>Pysäytä</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="198"/>
        <source>Generating preview for: %1</source>
        <translation>Luodaan esikatselua: %1</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="419"/>
        <source>Preview generation complete! Generated %1 previews.</source>
        <translation>Esikatselun luonti valmiina! %1 esikatselua luotu.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="423"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="426"/>
        <source>Preview Generation Complete</source>
        <translation>Esikatselun luonti valmiina</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="427"/>
        <source>Successfully generated %1 preview images.</source>
        <translation>%1 esikatselukuvaa luotu.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="68"/>
        <source>Select Conky Manager config file</source>
        <translation>Valitse Conky Manager:in asetustiedosto</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>You must run this program as normal user</source>
        <translation>Sinun täytyy suorittaa tämä ohjelma tavallisena käyttäjänä</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/settingsdialog.cpp" line="40"/>
        <location filename="../src/settingsdialog.cpp" line="62"/>
        <source>Select Conky Directory</source>
        <translation>Valitse Conky-kansio</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="83"/>
        <source>MX Conky Settings</source>
        <translation>MX Conky asetukset</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="91"/>
        <source>Search Paths</source>
        <translation>Hakupolut</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="92"/>
        <source>Autostart</source>
        <translation>Autom. käynnistys</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="167"/>
        <source>Conky Search Paths</source>
        <translation>Conky-hakupolut</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="173"/>
        <source>Add Path</source>
        <translation>Lisää polku</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="176"/>
        <source>Remove Path</source>
        <translation>Poista polku</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="179"/>
        <source>Edit Path</source>
        <translation>Muokkaa polkua</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="206"/>
        <source>Autostart Settings</source>
        <translation>Automaattinen käynnistys</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="209"/>
        <source>Start conky at system startup</source>
        <translation>Conky käynnistyy tietokoneen käynnistyksen aikana</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="212"/>
        <source>Startup delay (seconds):</source>
        <translation>Viive (sekuntia):</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="95"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="96"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
</context>
</TS>
